// Copyright 2018-2020 CERN
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// In applying this license, CERN does not waive the privileges and immunities
// granted to it by virtue of its status as an Intergovernmental Organization
// or submit itself to any jurisdiction.

package manager

import "github.com/opencloud-eu/reva/v2/pkg/siteacc/data"

// AccountsListenerCallback is the generic function type for accounts listeners.
type AccountsListenerCallback = func(AccountsListener, *data.Account)

// AccountsListener is an interface that listens to accounts events.
type AccountsListener interface {
	// AccountCreated is called whenever an account was created.
	AccountCreated(account *data.Account)
	// AccountUpdated is called whenever an account was updated.
	AccountUpdated(account *data.Account)
	// AccountRemoved is called whenever an account was removed.
	AccountRemoved(account *data.Account)
}
